@@ -1,4 +1,9 @@
 #!/usr/bin/env python
+import sys
+sys.path.insert(0,'..')
+import env
+#from env import setup
+#setup()
 from django.core.management import execute_manager
 import imp
 try:
@@ -12,5 +17,3 @@ import settings
 
 if __name__ == "__main__":
     execute_manager(settings)
-    from env import setup
-    setup()
